sqlobject.firebird.firebirdconnection module
============================================

.. automodule:: sqlobject.firebird.firebirdconnection
    :members:
    :undoc-members:
    :show-inheritance:
